==> pmml-model-1.6.9-sources.jar: org/dmg/pmml/baseline/Alternate.java <==

package org.dmg.pmml.baseline;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlElements;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.ContinuousDistribution;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.MissingElementException;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "Alternate", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "continuousDistribution"
})
@JsonRootName("Alternate")
@JsonPropertyOrder({
    "continuousDistribution"
})
@Added((org.dmg.pmml.Version.PMML_4_1))
public class Alternate
    extends org.dmg.pmml.PMMLObject
{

    @XmlElements({
        @XmlElement(name = "AnyDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.AnyDistribution.class),
        @XmlElement(name = "GaussianDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.GaussianDistribution.class),
        @XmlElement(name = "PoissonDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.PoissonDistribution.class),
        @XmlElement(name = "UniformDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.UniformDistribution.class)
    })
    @JsonProperty("ContinuousDistribution")
    @JsonTypeInfo(include = JsonTypeInfo.As.WRAPPER_OBJECT, use = JsonTypeInfo.Id.NAME)
    @JsonSubTypes({
        @JsonSubTypes.Type(name = "AnyDistribution", value = org.dmg.pmml.AnyDistribution.class),
        @JsonSubTypes.Type(name = "GaussianDistribution", value = org.dmg.pmml.GaussianDistribution.class),
        @JsonSubTypes.Type(name = "PoissonDistribution", value = org.dmg.pmml.PoissonDistribution.class),
        @JsonSubTypes.Type(name = "UniformDistribution", value = org.dmg.pmml.UniformDistribution.class)
    })
    private ContinuousDistribution continuousDistribution;
    private final static long serialVersionUID = 67371271L;

    public Alternate() {
    }

    @ValueConstructor
    public Alternate(
        @org.jpmml.model.annotations.Property("continuousDistribution")
        ContinuousDistribution continuousDistribution) {
        this.continuousDistribution = continuousDistribution;
    }

    public ContinuousDistribution requireContinuousDistribution() {
        if (this.continuousDistribution == null) {
            throw new MissingElementException(this, PMMLElements.ALTERNATE_CONTINUOUSDISTRIBUTION);
        }
        return this.continuousDistribution;
    }

    public ContinuousDistribution getContinuousDistribution() {
        return continuousDistribution;
    }

    public Alternate setContinuousDistribution(
        @org.jpmml.model.annotations.Property("continuousDistribution")
        ContinuousDistribution continuousDistribution) {
        this.continuousDistribution = continuousDistribution;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getContinuousDistribution());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.7.0-sources.jar: org/dmg/pmml/baseline/Alternate.java <==

package org.dmg.pmml.baseline;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlElements;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.ContinuousDistribution;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.MissingElementException;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "Alternate", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "continuousDistribution"
})
@JsonRootName("Alternate")
@JsonPropertyOrder({
    "continuousDistribution"
})
@Added((org.dmg.pmml.Version.PMML_4_1))
public class Alternate
    extends org.dmg.pmml.PMMLObject
{

    @XmlElements({
        @XmlElement(name = "AnyDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.AnyDistribution.class),
        @XmlElement(name = "GaussianDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.GaussianDistribution.class),
        @XmlElement(name = "PoissonDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.PoissonDistribution.class),
        @XmlElement(name = "UniformDistribution", namespace = "http://www.dmg.org/PMML-4_4", type = org.dmg.pmml.UniformDistribution.class)
    })
    @JsonProperty("ContinuousDistribution")
    @JsonTypeInfo(include = JsonTypeInfo.As.WRAPPER_OBJECT, use = JsonTypeInfo.Id.NAME)
    @JsonSubTypes({
        @JsonSubTypes.Type(name = "AnyDistribution", value = org.dmg.pmml.AnyDistribution.class),
        @JsonSubTypes.Type(name = "GaussianDistribution", value = org.dmg.pmml.GaussianDistribution.class),
        @JsonSubTypes.Type(name = "PoissonDistribution", value = org.dmg.pmml.PoissonDistribution.class),
        @JsonSubTypes.Type(name = "UniformDistribution", value = org.dmg.pmml.UniformDistribution.class)
    })
    private ContinuousDistribution continuousDistribution;
    private static final long serialVersionUID = 67371272L;

    public Alternate() {
    }

    @ValueConstructor
    public Alternate(
        @org.jpmml.model.annotations.Property("continuousDistribution")
        ContinuousDistribution continuousDistribution) {
        this.continuousDistribution = continuousDistribution;
    }

    public ContinuousDistribution requireContinuousDistribution() {
        if (this.continuousDistribution == null) {
            throw new MissingElementException(this, PMMLElements.ALTERNATE_CONTINUOUSDISTRIBUTION);
        }
        return this.continuousDistribution;
    }

    public ContinuousDistribution getContinuousDistribution() {
        return continuousDistribution;
    }

    public Alternate setContinuousDistribution(
        @org.jpmml.model.annotations.Property("continuousDistribution")
        ContinuousDistribution continuousDistribution) {
        this.continuousDistribution = continuousDistribution;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if (status == VisitorAction.CONTINUE) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getContinuousDistribution());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
